@@ -382,8 +382,7 @@ class MusePipeSample(object):
             True if yes, False if no.
         """
         if targetname not in self.targetnames:
-            upipe.print_error("ERROR: no Target named {name} in the defined sample".format(
-                                name=targetname))
+            upipe.print_error(f"No '{targetname}' in the defined Target Name List -- Aborting")
             return False
         else:
             return True
@@ -575,6 +574,9 @@ class MusePipeSample(object):
         Returns:
 
         """
+        if not self._check_targetname(targetname):
+            return
+
         if rot_pixtab:
             # We first use the offset table to rotate the pixtables
             upipe.print_info("========== ROTATION OF PIXTABLES ===============")
@@ -604,21 +606,27 @@ class MusePipeSample(object):
                                             **kwargs)
 
         if create_wcs:
-            # Creating the WCS reference frames. Full mosaic and individual
-            # Pointings.
+            # Creating the WCS reference frames. Full mosaic and individual Pointings.
             upipe.print_info("=========== CREATION OF WCS MASKS ==============")
-            mosaic_wcs = kwargs.pop("mosaic_wcs", True)
-            reference_cube = kwargs.pop("reference_cube", True)
+            # Do we create individual pointings cubes
             pointings_wcs = kwargs.pop("pointings_wcs", True)
+            # Create a mosaic WCS or not
+            mosaic_wcs = kwargs.pop("mosaic_wcs", True)
+
+            # Either a direct WCS cube name is provided and will be used
+            # Or an input reference cube which will be used to build the WCS cube
+            # Or none of those two. Default is None for both
+            wcs_refcube_name = kwargs.pop("wcs_refcube_name", None)
             refcube_name = kwargs.pop("refcube_name", None)
+
             full_ref_wcs = kwargs.pop("full_ref_wcs", None)
             default_comb_folder = self.targets[targetname].combcubes_path
-            folder_full_ref_wcs = kwargs.pop("folder_full_ref_wcs",
-                                             default_comb_folder)
+            folder_full_ref_wcs = kwargs.pop("folder_full_ref_wcs", default_comb_folder)
+
             self.create_reference_wcs(targetname=targetname,
                                       folder_offset_table=folder_offset_table,
                                       name_offset_table=name_offset_table,
-                                      reference_cube=reference_cube,
+                                      wcs_refcube_name=wcs_refcube_name,
                                       refcube_name=refcube_name,
                                       mosaic_wcs=mosaic_wcs,
                                       pointings_wcs=pointings_wcs,
@@ -810,6 +818,9 @@ class MusePipeSample(object):
         last_recipe: str or int [max of all recipes]
             Name or number of the first and last recipes to process
         """
+        if not self._check_targetname(targetname):
+            return
+
         # General print out
         upipe.print_info("---- Starting the Data Reduction for Target={0} ----".format(
                             targetname))
@@ -1126,10 +1137,8 @@ class MusePipeSample(object):
         self.init_combine(targetname=targetname, **kwargs)
         self.pipes_combine[targetname].run_combine(**kwargs)
 
-    def create_reference_wcs(self, targetname=None, pointings_wcs=True,
-                             mosaic_wcs=True, reference_cube=True,
-                             ref_wcs=None,
-                             refcube_name=None, **kwargs):
+    def create_reference_wcs(self, targetname=None, pointings_wcs=True, mosaic_wcs=True,
+                             wcs_refcube_name=None, refcube_name=None, ref_wcs=None, **kwargs):
         """Run the combine for individual exposures first building up
         a mask.
         """
@@ -1138,7 +1147,7 @@ class MusePipeSample(object):
         self.init_combine(targetname=targetname, **kwargs)
         self.pipes_combine[targetname].create_reference_wcs(pointings_wcs=pointings_wcs,
                                                             mosaic_wcs=mosaic_wcs,
-                                                            reference_cube=reference_cube,
+                                                            wcs_refcube_name=wcs_refcube_name,
                                                             refcube_name=refcube_name,
                                                             ref_wcs=ref_wcs,
                                                             folder_ref_wcs=folder_ref_wcs,
